import Toybox.Activity;
import Toybox.Graphics;
import Toybox.WatchUi;
import Toybox.AntPlus;


var curPower = 0;
var curCadence = 0;
var curBattery = 0;
var curState = 0;
var infoManufact = 0;
var infoModelNo = 0;
var infoModelSw1 = 0;
var infoModelSw2 = 0;
var prodSerial = 0;



class myBikePowerListener extends AntPlus.BikePowerListener {

    function initialize() {
        AntPlus.BikePowerListener.initialize();
    }

    function onDeviceStateUpdate(data) {
        if ( data != null ) {
            if ( data.state != null ) {
                curState = data.state; 
            }
        } else {    
            curState = 0;            
        }
    }



    function onBatteryStatusUpdate(data) {
        if ( data != null ) {
            if ( data.batteryStatus != null ) {
                curBattery = data.batteryStatus; 
            }
        } else {    
            curBattery = 0;            
        }
    }


    function onCalculatedPowerUpdate(data) {
        if ( data != null ) {
            if ( data.power != null ) {
                curPower = data.power;
            }
        } else {    
            curPower = 0;            
        }
    }


    function onCalculatedCadenceUpdate(data) {
        if ( data != null ) {
            if ( data.cadence != null ) {
                curCadence = data.cadence;
            }
        } else {    
            curCadence = 0;            
        }
    }

}

class TestPowerView extends WatchUi.DataField {

    var listener;
    var batStatus = "unknown";
    var devStatus = "dead";
    var bikePower;


    function initialize() {
        DataField.initialize();
    
        listener = new myBikePowerListener();
        bikePower = new AntPlus.BikePower(listener);

    }

    function compute(info as Activity.Info) as Void {

        
        var product = bikePower.getProductInfo(null);
        if ( product != null ) {
            prodSerial = product.serial;
            infoModelSw1 = product.swRevisionMain;
            infoModelSw2 = product.swRevisionSupplemental;
        }
        var manufact = bikePower.getManufacturerInfo(null);
        if ( manufact != null ) {
            infoManufact = manufact.manufacturerId;
            infoModelNo = manufact.modelNumber;
        }


        if ( curBattery == 0 ) {
            batStatus = "unknown";
        } else if ( curBattery == 1 ) {
            batStatus = "new";
        } else if ( curBattery == 2 ) {
            batStatus = "good";
        } else if ( curBattery == 3 ) {
            batStatus = "okay";
        } else if ( curBattery == 4 ) {
            batStatus = "low";
        } else if ( curBattery == 5 ) {
            batStatus = "critcal";
        } else if ( curBattery == 7 ) {
            batStatus = "invalid";
        } else if ( curBattery == 8 ) {
            batStatus = "cnt?";
        }

        if ( curState == 0 ) {
            devStatus = "dead";
        } else if ( curState == 1 ) {
            devStatus = "closed";
        } else if ( curState == 2 ) {
            devStatus = "searching";
        } else if ( curState == 3 ) {
            devStatus = "tracking";
        }

    }   // END Compute

    // Display the value you computed: 
    function onUpdate(dc as Dc) as Void {
    
        dc.setColor(Graphics.COLOR_BLACK, Graphics.COLOR_WHITE);

        dc.drawText(94, 10, Graphics.FONT_MEDIUM, "POWER", Graphics.TEXT_JUSTIFY_CENTER);
        dc.drawText(94, 2 + 30, Graphics.FONT_NUMBER_MEDIUM, curPower, Graphics.TEXT_JUSTIFY_CENTER);
        dc.drawText(188, 10, Graphics.FONT_MEDIUM, "RPM", Graphics.TEXT_JUSTIFY_CENTER);
        dc.drawText(188, 2 + 30, Graphics.FONT_NUMBER_MEDIUM, curCadence, Graphics.TEXT_JUSTIFY_CENTER);

        dc.drawText(140, 45 + 50, Graphics.FONT_MEDIUM, "Battery: " + batStatus, Graphics.TEXT_JUSTIFY_CENTER);
        dc.drawText(140, 70 + 50, Graphics.FONT_MEDIUM, "State: " + devStatus, Graphics.TEXT_JUSTIFY_CENTER);
        dc.drawText(140, 95 + 50, Graphics.FONT_MEDIUM, "Product Serial: " + prodSerial, Graphics.TEXT_JUSTIFY_CENTER);
        dc.drawText(140, 120 + 50, Graphics.FONT_MEDIUM, "Manufacturer ID: " + infoManufact, Graphics.TEXT_JUSTIFY_CENTER);
        dc.drawText(140, 145 + 50, Graphics.FONT_MEDIUM, "Model No: " + infoModelNo, Graphics.TEXT_JUSTIFY_CENTER);
        dc.drawText(140, 170 + 50, Graphics.FONT_MEDIUM, "Software: " + infoModelSw1 + "." + infoModelSw2, Graphics.TEXT_JUSTIFY_CENTER);


    }
}
